## PDFMathTranslate

PDF 科研论文翻译与双语对照。 - 📊 保留公式、图表、目录和注释 _([预览](#预览))_。 - 🌐 支持[多种语言](https://pdf2zh-next.com/supported_languages.html)，以及多样化的[翻译服务](https://pdf2zh-next.com/advanced/翻译服务文档.html)。 - 🤖 提供[命令行工具](https://pdf2zh-next.com/getting-started/USAGE_commandline.html)、[交互式用户界面](https://pdf2zh-next.com/getting-started/USAGE_webui.html)和[Docker](https://pdf2zh-next.com/getting-started/INSTALLATION_docker.html) 欢迎在 [GitHub Issues](https://github.com/PDFMathTranslate/PDFMathTranslate-next/issues) 或 [Telegram 群组](https://t.me/+Z9_SgnxmsmA5NzBl) 中提供反馈。 有关如何贡献的详细信息，请参阅 [贡献指南](https://pdf2zh-next.com/community/Contribution-Guide.html)。

## 更新

- [2025 年 6 月 4 日] 项目更名为 [PDFMathTranslate/PDFMathTranslate-next](https://github.com/PDFMathTranslate/PDFMathTranslate-next) 并迁移至此仓库 (by [@awwaawwa](https://github.com/awwaawwa)) - [2025 年 3 月 3 日] 实验性支持新后端 [BabelDOC](https://github.com/funstory-ai/BabelDOC) WebUI 作为实验性选项 (by [@awwaawwa](https://github.com/awwaawwa)) - [2025 年 2 月 22 日] 优化发布 CI 流程并完善 Windows-amd64 可执行文件打包 (by [@awwaawwa](https://github.com/awwaawwa)) - [2024 年 12 月 24 日] 翻译器现支持 [Xinference](https://github.com/xorbitsai/inference) 本地模型 _(by [@imClumsyPanda](https://github.com/imClumsyPanda))_ - [2024 年 12 月 19 日] 现可通过 `-cp` 参数支持非 PDF/A 格式文档 _(by [@reycn](https://github.com/reycn))_ - [2024 年 12 月 13 日] 新增后端支持 _(by [@YadominJinta](https://github.com/YadominJinta))_ - [2024 年 12 月 10 日] 翻译器现支持 Azure 平台上的 OpenAI 模型 _(by [@yidasanqian](https://github.com/yidasanqian))_

## 预览

## 在线服务 🌟

> [!NOTE] > > pdf2zh 2.0 目前不提供在线演示 你可以通过以下任意一个演示来试用我们的应用： - [v1.x 公共免费服务](https://pdf2zh.com/) 无需安装即可在线使用 _(推荐)_ - [沉浸式翻译 - BabelDOC](https://app.immersivetranslate.com/babel-doc/) 每月 1000 页免费额度 _(推荐)_ 请注意，演示环境的计算资源有限，请避免滥用。

## 安装与使用

### 如何安装 1. [**Windows EXE**](https://pdf2zh-next.com/getting-started/INSTALLATION_winexe.html) 推荐 Windows 用户使用 2. [**Docker**](https://pdf2zh-next.com/getting-started/INSTALLATION_docker.html) 推荐 Linux 用户使用 3. [**uv** (一个 Python 包管理器)](https://pdf2zh-next.com/getting-started/INSTALLATION_uv.html) 推荐 macOS 用户使用 --- ### 如何使用 1. [使用 **WebUI**](https://pdf2zh-next.com/getting-started/USAGE_webui.html) 2. [使用 **Zotero 插件**](https://github.com/guaguastandup/zotero-pdf2zh) (第三方程序) 3. [使用 **命令行**](https://pdf2zh-next.com/getting-started/USAGE_commandline.html) 针对不同的使用场景，我们提供了多种程序调用方式。更多信息请查看[此页面](./getting-started/getting-started.md)。

## 高级选项

详细说明请参阅我们的[高级用法文档](https://pdf2zh-next.com/advanced/advanced.html)，获取每个选项的完整列表。

## 二次开发 (APIs)

> [!NOTE] > > 目前暂未提供相关文档，后续会补充，请耐心等待。

## 语言代码

如果你不知道需要使用什么代码来翻译到你需要的语言，请查看[此文档](https://pdf2zh-next.com/advanced/Language-Codes.html)

## 致谢

    - [沉浸式翻译](https://immersivetranslate.com) 为本项目的活跃贡献者每月提供 Pro 会员兑换码，详情见：[CONTRIBUTOR_REWARD.md](https://github.com/funstory-ai/BabelDOC/blob/main/docs/CONTRIBUTOR_REWARD.md)

    - 1.x 版本：[Byaidu/PDFMathTranslate](https://github.com/Byaidu/PDFMathTranslate)

    - 新后端：[BabelDOC](https://github.com/funstory-ai/BabelDOC)

    - 文档合并：[PyMuPDF](https://github.com/pymupdf/PyMuPDF)

    - 文档解析：[Pdfminer.six](https://github.com/pdfminer/pdfminer.six)

    - 文档提取：[MinerU](https://github.com/opendatalab/MinerU)

    - 文档预览：[Gradio PDF](https://github.com/freddyaboulton/gradio-pdf)

    - 多线程翻译：[MathTranslate](https://github.com/SUSYUSTC/MathTranslate)

    - 布局解析：[DocLayout-YOLO](https://github.com/opendatalab/DocLayout-YOLO)

    - 文档标准：[PDF Explained](https://zxyle.github.io/PDF-Explained/), [PDF Cheat Sheets](https://pdfa.org/resource/pdf-cheat-sheets/)

    - 多语言字体：[Go Noto Universal](https://github.com/satbyy/go-noto-universal)

    - [Asynchronize](https://github.com/multimeric/Asynchronize/tree/master?tab=readme-ov-file)

    - [支持多进程的 Rich 日志记录](https://github.com/SebastianGrans/Rich-multiprocess-logging/tree/main)

## 提交代码前

我们欢迎贡献者积极参与，让 pdf2zh 变得更好。在您准备提交代码前，请参阅我们的[行为准则](https://pdf2zh-next.com/community/CODE_OF_CONDUCT.html)和[贡献指南](https://pdf2zh-next.com/community/Contribution-Guide.html)。

## 贡献者

![Alt](https://repobeats.axiom.co/api/embed/45529651750579e099960950f757449a410477ad.svg "Repobeats analytics image")

## Star History

###### 本页面的部分内容由 GPT 翻译，可能包含错误。